/*!
 * @jmshal/react-inline-svg v4.0.0-rc.1 (https://github.com/jmshal/react-inline-svg)
 * A simple and lightweight React component for loading SVG files so they can be styled with CSS.
 *
 * @license MIT
 * @author Jacob Marshall <git@jacobmarshall.co>
 */
(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('react')) :
    typeof define === 'function' && define.amd ? define(['exports', 'react'], factory) :
    (factory((global['@jmshal/react-inline-svg'] = {}),global.React));
}(this, (function (exports,React) { 'use strict';

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0

    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.

    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */
    /* global Reflect, Promise */

    var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };

    function __extends(d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }

    var __assign = function() {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };

    function __rest(s, e) {
        var t = {};
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
        if (s != null && typeof Object.getOwnPropertySymbols === "function")
            for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
                t[p[i]] = s[p[i]];
        return t;
    }

    var cache = new Map();

    function send(url) {
        return new Promise(function (resolve, reject) {
            var xhr = new XMLHttpRequest();
            xhr.onload = function () {
                var element;
                try {
                    element = xhr.responseXML.documentElement;
                }
                catch (err) {
                    reject(new Error("InlineSVG: Failed to parse response (" + url + ")."));
                    return;
                }
                if (element.nodeName.toLowerCase() !== 'svg') {
                    reject(new Error("InlineSVG: URL does not resolve to an SVG (" + url + ")."));
                    return;
                }
                resolve(element);
            };
            xhr.onerror = reject;
            xhr.open('GET', url, true);
            xhr.responseType = 'document';
            xhr.send();
        });
    }

    var root = document.createElement('svg');
    root.hidden = true;
    (document.head || document.body).appendChild(root);
    function svgToSymbol(svg) {
        var symbol = document.createElementNS('http://www.w3.org/2000/svg', 'symbol');
        for (var a = 0; a < svg.attributes.length; a++) {
            var attribute = svg.attributes[a];
            symbol.setAttribute(attribute.nodeName, attribute.nodeValue);
        }
        for (var c = 0; c < svg.childNodes.length; c++) {
            var childNode = svg.childNodes[c];
            symbol.appendChild(childNode.cloneNode(true));
        }
        return symbol;
    }
    function register(svg, id) {
        var symbol = svgToSymbol(svg);
        symbol.id = id;
        root.appendChild(symbol);
    }

    function load(src) {
        if (!cache.has(src)) {
            var id_1 = btoa(src)
                .replace(/[=-]/, '') // remove any base64 characters we can't use for ids
                .replace(/^([0-9])/, '_$1'); // add an underscore to the beginning of the id if it starts with a number
            var promise = send(src);
            var svg_1 = {
                id: id_1,
                isLoading: true,
                promise: promise.then(function () { }),
            };
            promise.then(function (element) {
                register(element, id_1);
                svg_1.isLoading = false;
            });
            cache.set(src, svg_1);
        }
        return cache.get(src);
    }

    var InlineSVG = /** @class */ (function (_super) {
        __extends(InlineSVG, _super);
        function InlineSVG(props) {
            var _this = _super.call(this, props) || this;
            var svg = load(props.src);
            _this.state = __assign({}, svg);
            _this.waitUntilLoaded(svg);
            return _this;
        }
        InlineSVG.prototype.componentWillReceiveProps = function (nextProps) {
            if (this.props.src !== nextProps.src) {
                var svg = load(nextProps.src);
                this.setState(__assign({}, svg));
                this.waitUntilLoaded(svg);
            }
        };
        InlineSVG.prototype.waitUntilLoaded = function (svg) {
            var _this = this;
            if (svg.isLoading) {
                svg.promise.then(function () {
                    // Ensure that by the time the SVG has been loaded, the id is still the same.
                    // If it's not - that means the `src` has changed since we started waiting.
                    if (_this.state.id === svg.id) {
                        _this.setState(__assign({}, svg));
                    }
                });
            }
        };
        InlineSVG.prototype.render = function () {
            var _a = this.state, id = _a.id, isLoading = _a.isLoading;
            var _b = this.props, src = _b.src, props = __rest(_b, ["src"]);
            return (React.createElement("svg", __assign({}, props), !isLoading &&
                React.createElement("use", { xlinkHref: '#' + id, href: '#' + id })));
        };
        return InlineSVG;
    }(React.Component));

    exports.InlineSVG = InlineSVG;
    exports.preload = load;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=react-inline-svg.js.map
